import type { Config } from '../types';
/**
 * 项目构建公共配置, 可通过`project.config.js`自定义配置.
 * 注意读取配置前设置`process.env.NODE_ENV`为对应值, 不然开发模式可能没有读取本地配置.
 */
declare const config: Config;
/**
 * 加载自定义配置文件合并到配置对象中.
 *
 * @param cfgFiles 配置文件或者文件列表, 相对于项目根路径解析.
 */
declare function loadCustomConfigFiles(cfgFiles: string | string[]): void;
/**
 * 新增或者修改配置.
 *
 * @template T Type of extended config.
 * @param cfg
 */
declare function useConfig<T extends Partial<Config> = Partial<Config>>(cfg: T): void;
/**
 * 设定配置默认值, 未设置值才赋值默认值, 如果原值为`undefined`也表示设置过值.
 *
 * @template T Type of extended config.
 * @param cfg
 */
declare function useDefaultConfig<T extends Partial<Config> = Partial<Config>>(cfg: T): void;
export default config;
export { loadCustomConfigFiles, useConfig, useDefaultConfig };
