"use strict";

var __createBinding = this && this.__createBinding || (Object.create ? function (o, m, k, k2) {
  if (k2 === undefined) k2 = k;
  Object.defineProperty(o, k2, {
    enumerable: true,
    get: function () {
      return m[k];
    }
  });
} : function (o, m, k, k2) {
  if (k2 === undefined) k2 = k;
  o[k2] = m[k];
});
var __setModuleDefault = this && this.__setModuleDefault || (Object.create ? function (o, v) {
  Object.defineProperty(o, "default", {
    enumerable: true,
    value: v
  });
} : function (o, v) {
  o["default"] = v;
});
var __importStar = this && this.__importStar || function (mod) {
  if (mod && mod.__esModule) return mod;
  var result = {};
  if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
  __setModuleDefault(result, mod);
  return result;
};
var __importDefault = this && this.__importDefault || function (mod) {
  return mod && mod.__esModule ? mod : {
    "default": mod
  };
};
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useDefaultConfig = exports.useConfig = exports.loadCustomConfigFiles = void 0;
const path_1 = __importDefault(require("path"));
const merge_1 = __importStar(require("../utils/merge"));
const resolveOutputDir_1 = __importDefault(require("../internals/resolveOutputDir"));
const getUserConfig_1 = __importDefault(require("./getUserConfig"));
const defaultConfig = {
  projectRoot: process.cwd(),
  sourceDir: 'src',
  outputDir: path_1.default.join(process.cwd(), 'dist')
};
const userConfig = (0, getUserConfig_1.default)() || {};
let {
  projectRoot,
  sourceDir,
  outputDir
} = userConfig;
Object.keys(defaultConfig).forEach(key => {
  const cfgKey = key;
  if ({}.hasOwnProperty.call(userConfig, cfgKey)) {
    delete userConfig[cfgKey];
  }
});
if (!projectRoot) {
  projectRoot = defaultConfig.projectRoot;
} else {
  projectRoot = path_1.default.resolve(defaultConfig.projectRoot, projectRoot);
}
if (!sourceDir) {
  sourceDir = defaultConfig.sourceDir;
} else {
  // 统一相对路径
  if (path_1.default.isAbsolute(sourceDir)) {
    sourceDir = path_1.default.relative(projectRoot, sourceDir);
  }
  // 去除头部`./`
  if (sourceDir.startsWith('./')) {
    sourceDir = sourceDir.replace('./', '');
  }
  // 去除尾部斜线`/`
  if (sourceDir.endsWith('/')) {
    sourceDir = sourceDir.replace(/\/+$/, '');
  }
}
if (!outputDir) {
  outputDir = (0, resolveOutputDir_1.default)(projectRoot);
} else {
  outputDir = path_1.default.resolve(projectRoot, outputDir);
}
/**
 * 项目构建公共配置, 可通过`project.config.js`自定义配置.
 * 注意读取配置前设置`process.env.NODE_ENV`为对应值, 不然开发模式可能没有读取本地配置.
 */
const config = {
  projectRoot,
  sourceDir,
  outputDir
};
// 合并用户配置
(0, merge_1.default)(config, userConfig);
/**
 * 加载自定义配置文件合并到配置对象中.
 *
 * @param cfgFiles 配置文件或者文件列表, 相对于项目根路径解析.
 */
function loadCustomConfigFiles(cfgFiles) {
  const files = [];
  if (typeof cfgFiles === 'string') {
    files.push(cfgFiles);
  } else if (Array.isArray(cfgFiles)) {
    cfgFiles.forEach(name => files.push(name));
  }
  const customConfig = (0, getUserConfig_1.default)(config.projectRoot, files);
  if (customConfig) {
    (0, merge_1.default)(config, customConfig);
  }
}
exports.loadCustomConfigFiles = loadCustomConfigFiles;
/**
 * 新增或者修改配置.
 *
 * @template T Type of extended config.
 * @param cfg
 */
function useConfig(cfg) {
  if (cfg && typeof cfg === 'object') {
    (0, merge_1.default)(config, cfg);
  }
}
exports.useConfig = useConfig;
/**
 * 设定配置默认值, 未设置值才赋值默认值, 如果原值为`undefined`也表示设置过值.
 *
 * @template T Type of extended config.
 * @param cfg
 */
function useDefaultConfig(cfg) {
  if (cfg && typeof cfg === 'object') {
    (0, merge_1.mergeDefault)(config, cfg);
  }
}
exports.useDefaultConfig = useDefaultConfig;
exports.default = config;