"use strict";

var __importDefault = this && this.__importDefault || function (mod) {
  return mod && mod.__esModule ? mod : {
    "default": mod
  };
};
Object.defineProperty(exports, "__esModule", {
  value: true
});
const path_1 = __importDefault(require("path"));
const fs_extra_1 = __importDefault(require("fs-extra"));
const logging_1 = __importDefault(require("../utils/logging"));
/**
 * copy-node-modules没处理本地文件依赖形式npm包，手动复制本地依赖包.
 *
 * @param src 源目录.
 * @param target 目标目录.
 * @param pkgs Package json dependencies, 如
 * [
 *  { name: 'mini-ali-ui', version: '1.3.8' },
 *  { name: '@babel/runtime', version: '7.14.8' },
 *  { name: 'regenerator-runtime', version: '0.13.9' }
 * ]
 * @param localPkgs 本地依赖包数组.
 */
function copyPkgs(src, target, pkgs, localPkgs) {
  if (!(localPkgs === null || localPkgs === void 0 ? void 0 : localPkgs.length)) {
    return;
  }
  const pkgNames = pkgs.map(pkg => {
    const {
      name
    } = pkg;
    // const { name, version } = pkg;
    // logging.log(`package name: ${name}, version: ${version}`);
    return name;
  });
  localPkgs.forEach(name => {
    if (!pkgNames.includes(name)) {
      logging_1.default.log('package', name, 'not copied');
      const nodeModulePath = path_1.default.join('node_modules', name);
      const srcPath = path_1.default.join(src, nodeModulePath);
      const destPath = path_1.default.join(target, nodeModulePath);
      logging_1.default.log('copy', srcPath.replace(src, '').replace(/^[\\/]/, ''), 'to', destPath.replace(src, '').replace(/^[\\/]/, ''));
      fs_extra_1.default.copySync(srcPath, destPath);
    }
  });
}
exports.default = copyPkgs;