"use strict";

var __importDefault = this && this.__importDefault || function (mod) {
  return mod && mod.__esModule ? mod : {
    "default": mod
  };
};
Object.defineProperty(exports, "__esModule", {
  value: true
});
const path_1 = __importDefault(require("path"));
const fs_extra_1 = __importDefault(require("fs-extra"));
const config_1 = __importDefault(require("../config"));
const copyNodeModules_1 = __importDefault(require("../internals/copyNodeModules"));
const getMiniProject_1 = __importDefault(require("./getMiniProject"));
/**
 * 复制package.json中dependencies依赖到构建输出目录，可用于小程序开发者工具单独打开构建输出目录。
 * 如果不传递src和dest参数，以项目根目录作为src，复制依赖到小程序miniprogramRoot和pluginRoot目录。
 * 注：依赖包被复制到目标目录下的`node_modules`目录中而不是直接放到目标目录下，复制前会删除目标目录下的`node_modules`。
 *
 * @param src Source directory containing package.json file.
 * @param dest Destination directory to copy modules to (modules will be copied to `dest/node_modules` directory).
 * @param clean 是否在复制前删除`dest/node_modules`, 默认`true`.
 * @returns
 */
async function copyDeps(src, dest, clean = true) {
  const realDest = dest => {
    return path_1.default.join(dest, 'node_modules');
  };
  if (src && dest) {
    if (clean) {
      await fs_extra_1.default.remove(realDest(dest));
    }
    await (0, copyNodeModules_1.default)(src, dest);
    return;
  }
  let miniprogramRoot;
  let pluginRoot;
  const miniConfig = (0, getMiniProject_1.default)(config_1.default.projectRoot);
  if (miniConfig === null || miniConfig === void 0 ? void 0 : miniConfig.miniprogramRoot) {
    miniprogramRoot = path_1.default.join(config_1.default.projectRoot, miniConfig.miniprogramRoot);
    if (clean) {
      await fs_extra_1.default.remove(realDest(miniprogramRoot));
    }
  }
  if (miniConfig === null || miniConfig === void 0 ? void 0 : miniConfig.pluginRoot) {
    pluginRoot = path_1.default.join(config_1.default.projectRoot, miniConfig.pluginRoot);
    if (clean) {
      await fs_extra_1.default.remove(realDest(pluginRoot));
    }
  }
  if (miniprogramRoot) {
    await (0, copyNodeModules_1.default)(config_1.default.projectRoot, miniprogramRoot);
  }
  if (pluginRoot) {
    await (0, copyNodeModules_1.default)(config_1.default.projectRoot, pluginRoot);
  }
}
exports.default = copyDeps;