"use strict";

var __importDefault = this && this.__importDefault || function (mod) {
  return mod && mod.__esModule ? mod : {
    "default": mod
  };
};
Object.defineProperty(exports, "__esModule", {
  value: true
});
const fs_1 = __importDefault(require("fs"));
const os_1 = __importDefault(require("os"));
const path_1 = __importDefault(require("path"));
const dynamicRequire_1 = __importDefault(require("./dynamicRequire"));
/**
 * 解析`tsconfig.json`为JSON对象, tsconfig.json为json5格式不能用JSON.parse解析, json5支持注释.
 *
 * @param tsConfigPath `tsconfig.json`路径或者`projectRoot`项目根目录,
 * 如果为目录继续在目录中查找`tsconfig.json`, 默认`process.cwd()`.
 * @returns
 * @see https://www.typescriptlang.org/tsconfig/
 */
function getTsConfig(tsConfigPath = process.cwd()) {
  let tsConfig;
  if (!fs_1.default.existsSync(tsConfigPath)) {
    return tsConfig;
  }
  const stat = fs_1.default.statSync(tsConfigPath);
  // projectRoot directory
  if (stat.isDirectory()) {
    tsConfigPath = path_1.default.join(tsConfigPath, 'tsconfig.json');
  }
  if (!fs_1.default.existsSync(tsConfigPath)) {
    return tsConfig;
  }
  let ts;
  try {
    ts = (0, dynamicRequire_1.default)('typescript');
  } catch (_a) {
    // typescript may not installed
  }
  if (ts) {
    // 读取tsconfig.json, tsconfig.json为json5格式不能用JSON.parse解析, json5支持注释
    const result = ts.readConfigFile(tsConfigPath, ts.sys.readFile);
    if (result.error) {
      // 参考`ts-loader`格式化ts错误
      const msg = ts.flattenDiagnosticMessageText(result.error.messageText, os_1.default.EOL);
      throw new Error(`TS${result.error.code}: ${msg}`);
    }
    tsConfig = result.config;
  }
  return tsConfig;
}
exports.default = getTsConfig;