"use strict";

var __importDefault = this && this.__importDefault || function (mod) {
  return mod && mod.__esModule ? mod : {
    "default": mod
  };
};
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.mergeDefault = void 0;
const isObject_1 = __importDefault(require("./isObject"));
const cloneArray = ary => {
  if (Array.isArray(ary)) {
    ary = ary.map(val => {
      if ((0, isObject_1.default)(val)) {
        val = merge({}, val);
      } else if (Array.isArray(val)) {
        val = cloneArray(ary);
      }
      return val;
    });
  }
  return ary;
};
/**
 * 将源对象和目标对象合并, 如果值为对象进行深度合并如果为数组进行赋值覆盖不拼接.
 *
 * @param target 目标对象.
 * @param source 源对象.
 * @param keys 给定source keys，如果未提供则获取源对象keys.
 * @returns 目标对象.
 */
function merge(target, source, keys) {
  keys = keys || Object.keys(source);
  keys.forEach(key => {
    let srcVal = source[key];
    if ((0, isObject_1.default)(srcVal)) {
      srcVal = merge({}, srcVal);
    } else if (Array.isArray(srcVal)) {
      srcVal = cloneArray(srcVal);
    }
    let targetVal = target[key];
    if ((0, isObject_1.default)(targetVal) && (0, isObject_1.default)(srcVal)) {
      // 对象合并
      targetVal = merge(targetVal, srcVal);
    } else if (Array.isArray(targetVal) && Array.isArray(srcVal)) {
      // 数组直接覆盖
      targetVal = srcVal;
    } else {
      // 其它覆盖
      targetVal = srcVal;
    }
    target[key] = targetVal;
  });
  return target;
}
/**
 * 设定目标对象默认值, 只有当源对象key在目标对象中不存在时才赋值给目标对象,
 * 如果源对象和目标对象相同key都为对象，则递归调用处理默认值.
 *
 * @param target 目标对象.
 * @param source 源对象.
 * @returns 目标对象.
 */
function mergeDefault(target, source) {
  const keys = Object.keys(source);
  keys.forEach(key => {
    let srcVal = source[key];
    if ((0, isObject_1.default)(srcVal)) {
      srcVal = merge({}, srcVal);
    } else if (Array.isArray(srcVal)) {
      srcVal = cloneArray(srcVal);
    }
    if (!{}.hasOwnProperty.call(target, key)) {
      // 目标对象不存在源对象key时才设置值
      target[key] = srcVal;
      return;
    }
    const targetVal = target[key];
    if ((0, isObject_1.default)(targetVal) && (0, isObject_1.default)(srcVal)) {
      // 对象合并或者设置默认值
      target[key] = mergeDefault(targetVal, srcVal);
    }
  });
  return target;
}
exports.mergeDefault = mergeDefault;
exports.default = merge;