"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
/**
 * 设置 `process.env.NODE_ENV` 值, `dev` => `development`, `build` => `production`.
 * 注：如果 `process.env.NODE_ENV` 已经有值则不作处理.
 * 通常需要在程序运行最开始确保 `NODE_ENV`, 故该模块不做统一导出避免副作用.
 *
 * @param cmd `dev`、`build` or others.
 * @param force 如果 `NODE_ENV` 已经有值且跟 cmd 不对应, 是否强制设置跟 cmd 对应.
 * 在某些情况下可能预设过 NODE_ENV, 比如 aci 配置文件中设置了 `NODE_ENV` 为 `test`.
 */
function ensureNodeEnv(cmd, force) {
  switch (cmd) {
    case 'dev':
      if (!('NODE_ENV' in process.env)) {
        process.env.NODE_ENV = 'development';
      } else if (process.env.NODE_ENV !== 'development' && force) {
        process.env.NODE_ENV = 'development';
      }
      break;
    case 'build':
      if (!('NODE_ENV' in process.env)) {
        process.env.NODE_ENV = 'production';
      } else if (process.env.NODE_ENV !== 'production' && force) {
        process.env.NODE_ENV = 'production';
      }
      break;
    default:
      break;
  }
}
exports.default = {
  ensureNodeEnv,
  isDev() {
    return process.env.NODE_ENV === 'development';
  },
  isProd() {
    return process.env.NODE_ENV === 'production';
  }
};