declare type Any = any;
interface Resolve {
    /**
     * 基于项目根路径解析相对路径.
     *
     * @param dirPath 项目根下面的子目录路径.
     * @returns 返回基于项目根路径的绝对路径.
     */
    (...dirPath: string[]): string;
    /**
     * 基于项目根`node_modules`解析模块路径.
     *
     * @param modulePath module path.
     * @returns 模块绝对路径.
     */
    module: (...modulePath: string[]) => string;
    /**
     * `require` alias function.
     * 注意：传递绝对路径模块路径，相对路径会相对于`resolve`文件所在路径，可能跟预期不一样.
     * 可以使用`require.resolve`解析相对路径为绝对路径.
     *
     * @template T Type of module to be required.
     * @param modulePath module path.
     * @returns 模块绝对路径.
     */
    require: <T = Any>(modulePath: string) => T;
    /**
     * 项目根路径，通常为`package.json`所在目录，默认`process.cwd`，
     * 外部可以主动设置项目根路径，可以用于npm link本地开发.
     */
    projectRoot?: string;
}
/**
 * 基于项目根路径解析相对路径.
 *
 * @param dirPath 项目根下面的子目录路径.
 * @returns 返回基于项目根路径的绝对路径.
 */
declare const resolve: Resolve;
export default resolve;
export type { Resolve };
