/**
 * @see https://www.npmjs.com/package/copy-node-modules
 */
declare module 'copy-node-modules' {
  interface Pkg {
    name: string;
    version: string;
  }

  /**
   * Copy all modules listed in `dependencies` or/and `devDependencies` field of `package.json` to destination directory.
   * 
   * @param src Source directory containing package.json file.
   * @param dest Destination directory to copy modules to (modules will be copied to `dest/node_modules` directory).
   * @param opts Options.
   * @param cbk A callback which is called when all copy tasks have finished or error occurs,
   * results is an array contains copied modules, each item is an object as {name: 'xxx', version: 'xxx'}.
   * @see https://www.npmjs.com/package/copy-node-modules#copynodemodulessrcdir-dstdir-options-callback
   */
  interface CopyNodeModules {
    (
      src: string,
      dest: string,
      opts?: {
        /**
         * boolean value, defaults to false, showing whether modules in devDependencies field of package.json
         * should also be copied (when it's set to true).
         */
        devDependencies?: boolean;
        /**
         * integer value, max number of root packages whose files are being copied concurrently.
         */
        concurrency?: number;
        /**
         * RegExp or function that accepts one value (the full path) and returns a boolean (copy on true).
         */
        filter?: RegExp | ((fullpath: string) => boolean);
      },
      cbk?: (err: unknown, pkgs: Pkg[]) => void
    ): void;
  }

  const copyNodeModules: CopyNodeModules;

  export default copyNodeModules;

  export type { Pkg };
}